.. image:: https://readthedocs.org/projects/zopeapponlinehelp/badge/?version=latest
        :target: http://zopeapponlinehelp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://travis-ci.org/zopefoundation/zope.app.onlinehelp.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.app.onlinehelp
        :alt: Build Status

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.app.onlinehelp/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.app.onlinehelp?branch=master
        :alt: Code Coverage

This package provides a framework for creating help pages for Zope 3
applications. ZCML directives are used to minimize the overhead of creating
new help pages.

Documentation is hosted at https://zopeapponlinehelp.readthedocs.io
